import parasail
from unittest import TestCase, main


def print_cigar_attributes(cigar):
    print(cigar)
    print(cigar.seq)
    print(cigar.len)
    print(cigar.beg_query)
    print(cigar.beg_ref)
    print(cigar.decode)


def print_traceback_attributes(traceback):
    print(traceback)
    print(traceback.query)
    print(traceback.comp)
    print(traceback.ref)


class Tests(TestCase):

    def test0(self):
        result = parasail.sw("asdf", "asdf", 10, 1, parasail.blosum62)
        with self.assertRaises(AttributeError):
            print_cigar_attributes(result.cigar)

    def test1(self):
        result = parasail.sw("asdf", "asdf", 10, 1, parasail.blosum62)
        with self.assertRaises(AttributeError):
            print_traceback_attributes(result.traceback)

    def test2(self):
        result = parasail.sw_trace("asdf", "asdf", 10, 1, parasail.blosum62)
        print_cigar_attributes(result.cigar)

    def test3(self):
        result = parasail.sw_trace("asdf", "asdf", 10, 1, parasail.blosum62)
        print_traceback_attributes(result.traceback)


if __name__ == '__main__':
    main()



import os
import parasail
from unittest import TestCase, main
from tempfile import NamedTemporaryFile


def create_input_file(filename):
    with open(filename, 'w') as fp:
        fp.write('''>AF0017_1 COG1250 # Protein_GI_number: 11497638 # Func_class: I Lipid transport and metabolism  # Function: 3-hydroxyacyl-CoA dehydrogenase # Organism: Archaeoglobus fulgidus
MMVLEIRNVAVIGAGSMGHAIAEVVAIHGFNVKLMDVSEDQLKRAMEKIEEGLRKSYERGYISEDPEKVLKRIEATADLIEVAKDADLVIEAIPEIFDLKKKVFSEIEQYCPDHTIFATNTSSLSITKLAEATKRPEKFIGMHFFNPPKILKLLEIVWGEKTSEETIRIVEDFARKIDRIIIHVRKDVPGFIVNRIFVTMSNEASWAVEMGEGTIEEIDSAVKYRLGLPMGLFELHDVLGGGSVDVSYHVLEYYRQTLGESYRPSPLFERLFKAGHYGKKTGKGFYDWSEGKTNEVPLRAGANFDLLRLVAPAVNEAAWLIEKGVASAEEIDLAVLHGLNYPRGLLRMADDFGIDSIVKKLNELYEKYNGEERYKVNPVLQKMVEEGKLGRTTGEGFYKYGD
>AF0017_2_COG1024_#_Protein_GI_number: 11497638 # Func_class: I Lipid transport and metabolism  # Function: Enoyl-CoA hydratase/carnithine racemase # Organism: Archaeoglobus fulgidus
GNYEFVKVEKEGKVGVLKLNRPRRANALNPTFLKEVEDALDLLERDEEVRAIVIAGEGKNFCAGADIAMFASGRPEMVTEFSQLGHKVFRKIEMLSKPVIAAIHGAAVGGGFELAMACDLRVMSERAFLGLPELNLGIIPGWGGTQRLAYYVGVSKLKEVIMLKRNIKPEEAKNLGLVAEVFPQERFWDEVMKLAREVAELPPLAVKYLKKVIALGTMPALETGNLAESEAGAVIALTDDVAEGIQAFNYRRKPNFRGR
''')


class Tests(TestCase):

    def setUp(self):
        self.tmpfile = NamedTemporaryFile()
        create_input_file(self.tmpfile.name)

    def tearDown(self):
        os.unlink(self.tmpfile.name)
        os.path.exists(self.tempfile.name)

    def work(self):
        sequences = parasail.sequences_from_file(self.tmpfile)
        print(len(sequences))
        print(len(sequences[0]))
        print(sequences[0])
        print(len(sequences[-1]))
        print(sequences[-1])
        print(sequences[0][0])
        with self.assertRaises(TypeError):
            print(sequences['asdf'])
        with self.assertRaises(TypeError):
            print(sequences[0]['asdf'])
        with self.assertRaises(IndexError):
            print(sequences[1000000])
        with self.assertRaises(IndexError):
            print(sequences[-1000000])
        with self.assertRaises(IndexError):
            print(sequences[0][1000000])
        with self.assertRaises(IndexError):
            print(sequences[0][-1000000])
        print("name:    '{}'".format(sequences[0].name))
        print("comment: '{}'".format(sequences[0].comment))
        print("seq:     '{}'".format(sequences[0].seq))
        print("qual:    '{}'".format(sequences[0].qual))
        print("characters: {}".format(sequences.characters))
        print("shortest:   {}".format(sequences.shortest))
        print("longest:    {}".format(sequences.longest))
        print("mean:       {}".format(sequences.mean))
        print("stddev:     {}".format(sequences.stddev))
        result = parasail.sw(str(sequences[0]), str(sequences[1]), 10, 1, parasail.blosum62)
        print(result.score)
        result = parasail.sw(sequences[0], sequences[1], 10, 1, parasail.blosum62)
        print(result.score)


if __name__ == '__main__':
    main()



import parasail
from unittest import TestCase, main


class Tests(TestCase):

    def print_traceback_attributes(self, traceback):
        print(traceback)
        print(traceback.query)
        print(traceback.comp)
        print(traceback.ref)

    def test1(self):
        matrix = parasail.matrix_create("ACGT",  2,  1)
        result = parasail.sw_trace("ACGT", "AcgT", 10, 1, matrix)
        traceback = result.traceback
        self.print_traceback_attributes(traceback)

    def test21(self):
        matrix = parasail.matrix_create("ACGTacgt",  2,  1,  True)
        result = parasail.sw_trace("ACGT", "AcgT", 10, 1, matrix)
        traceback = result.traceback
        self.print_traceback_attributes(traceback)

    def test22(self):
        matrix = parasail.matrix_create("ACGTacgt",  2,  1,  True)
        result = parasail.sw_trace("ACGT", "AcgT", 10, 1, matrix)
        traceback = result.get_traceback(case_sensitive=True)
        self.print_traceback_attributes(traceback)

    def test3(self):
        parasail.set_case_sensitive(True)
        matrix = parasail.matrix_create("ACGTacgt",  2,  1)
        result = parasail.sw_trace("ACGT", "AcgT", 10, 1, matrix)
        traceback = result.traceback
        self.print_traceback_attributes(traceback)

    def test4(self):
        parasail.set_case_sensitive(True)
        matrix = parasail.matrix_create("ACGT",  2,  1)
        result = parasail.sw_trace("ACGT", "AcgT", 10, 1, matrix)
        traceback = result.traceback
        self.print_traceback_attributes(traceback)


if __name__ == '__main__':
    main()
